* Figure 1 dofile
* substantive effects graph using -coefplot-

* using data: "icc.govt.data.dta" & "figure 1 data.dta"

************************************
* Step #1: collecting the estimates
************************************
* collecting incidence rate ratio (IRR) for three indicators of ICC prosecutorial effects
* including 95% confidence intervals (upper bound (ub) and lower bound (lb))
* ratification IRR from Model 1; icc action effect from Model 2; domestic crime statute effect from Model 3
* Note: I did not use Model 4 because of high collinearity between ratification and csr

*** govt models ***
* use "icc.govt.data.dta"
set more off
*MODEL 1: ratification
xtnbreg govbestosv2 icc_ratification polity ruleoflaw cw rebbest_avg_filled post_icc i.year, irr
*MODEL 2: ICC actions
xtnbreg govbestosv2 icc_action_3ma polity ruleoflaw cw rebbest_avg_filled post_icc i.year, irr
*MODEL 3: national criminal law reform
xtnbreg govbestosv2 csr polity ruleoflaw cw rebbest_avg_filled post_icc i.year, irr

*** rebel models ***
* use "icc.rebel.data.dta"
set more off 
* model 1: ratification
xtnbreg rebbest icc_ratification polity post_icc rebstrength govbestosv2, nolog re irr
* model 2: ICC actions
xtnbreg rebbest icc_action_3ma polity post_icc rebstrength govbestosv2, nolog re irr
* model 3: national criminal law
xtnbreg rebbest csr ruleoflaw polity post_icc rebstrength govbestosv2, nolog re irr

* this step creates a stata dataset with 7 vars: 
* 1) indicators for prosecutorial risk, 2) govt, 3) govt_lb, 4) gov_ub, 5) rebel, 6) rebel_lb, 7) rebel_ub
* save "figure 1 data.dta"
 
**************************************************
* Step #2: making a temporary matrix using -mkmat-
**************************************************
* coefficient plot (coefplot) only works with saved estimates, 
* so, before implementing -coefplot-, make a temporary matrix 
* collecting the estimates from step 1.

* use "figure 1 data.dta"

matrix drop X
mkmat govt govt_lb govt_ub rebel rebel_lb rebel_ub, matrix(X) rownames(indicators)


**********************************
* Step #3: graph using -coefplot-
********************************** 

* coefplot is an add-on program
ssc install coefplot

coefplot (matrix(X[,1]), ci((X[,2] X[,3])) label(Governments) mfcolor(white) mlcolor(black) ciopts(lcolor(black))) 
	(matrix(X[,4]), ci((X[,5] X[,6])) xline(100, lc(black) lp(dot)) label(Rebels) mfcolor(black) mlcolor(black) ciopts(lcolor(black)) 
	xscale(range(0, 200)) xtitle("number of civilian deaths"))








